(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5078,        144]*)
(*NotebookOutlinePosition[      5978,        176]*)
(*  CellTagsIndexPosition[      5891,        170]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["EtaOpt - single junction for different concentrations", "Title"],

Cell["by Gerg\[ODoubleDot] L\[EAcute]tay, Fraunhofer ISE (2001)", \
"Subsubtitle"],

Cell["\<\
    Fraunhofer Institute for Solar Energy Systems
    Department: Solar Cells - Materials and Technology
    Heidenhofstrasse 2
    79100 Freiburg
    Germany
    Fax:   ++49-(0)761-4588-5251
    Fax:   ++49-(0)761-4588-9000
    email: letay@ise.fhg.de\
\>", "SmallText"],

Cell[CellGroupData[{

Cell["Abstract", "Section"],

Cell["This notebook finds the maximum value  for a single junction", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation", "Section"],

Cell[BoxData[
    \(Needs["\<etaOpt`\>"]\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(eta = 
      etaOpt . new[name \[Rule] "\<single junction\>", 
          item \[Rule] \[IndentingNewLine]mechStack . 
              new[name \[Rule] "\<cell\>", 
                item \[Rule] {\[IndentingNewLine]monoStack . 
                      new[name \[Rule] "\<cell\>", 
                        item \[Rule] {\[IndentingNewLine]oneDiodeJunction . 
                              new[name \[Rule] "\<cell\>", 
                                temperature \[Rule] 293, no \[Rule] 1, 
                                nu \[Rule] 
                                  0]\[IndentingNewLine]}]\[IndentingNewLine]}]\
, \[IndentingNewLine]spectrum \[Rule] 
            spectrum . 
              new[\[IndentingNewLine]name \[Rule] "\<AM1_5d/am15d.dat\>", \
\[IndentingNewLine]powerOfOneSun \[Rule] 1000, 
                concentration \[Rule] 
                  1000], \[IndentingNewLine]bandgapRange \[Rule] {{0.5, 2, 
                0.1}}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    InterpretationBox["\<\"-\\!\\(etaOpt\\)-\"\>",
      StringForm[ "-`1`-", etaOpt],
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(eta . calcEtaMax[bandgapRangeList \[Rule] {{0.5, 2}}]\)], "Input"],

Cell[BoxData[
    \({{0.98046875`}, {48.11900503412635`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?calcEtaMax\)\)], "Input"],

Cell[BoxData[
    \("calcEtaMax[] tries to find the maximum  efficiency for a specified \
range. \n\n Options (given values are defaults):\n   bandgapRangeList->{}... \
This option must be specified, and gives the inital  set of bandgaps.\n   \
finestStep->0.01....... if all bandgapsteps are less or equal to this the  \
calculation stops.\n   stepsPerInterval->3... how many points should be \
calculated in each  interval. Must be bigger than 3.\n   \
debug->False........... If set to true some debug information will be  \
printed on the screen during calc.\n\n I.e. for a tandem cell:  \
calcEtaMax[bandgapRangeList->{{1,2},{0.4,1.4}},finestStep->0.01, \
stepsPerInterval->4].\n In a first step eta is calculated for all bandgaps \
defined by step  ({1,1.25,1.5,1.75,2} for the top cell \
{0.4,0.65,0.9,1.15,1.4} for the bottom  cell. Than the maximum is calculated. \
The new range is set to maxvalue +/-  interval size. So if 1.4 eV was found \
in a first step for the top cell the  new interval becomes 1.4 +/- 0.25. This \
is devided in 4 steps.....This  iteration continous until the stepsize is \
less or equal to finestStep.\n"\)], "Print",
  CellTags->"Info3212169303-1843986"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 723}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1016, 696},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowCellBracket->True,
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3212169303-1843986"->{
    Cell[3859, 123, 1191, 17, 535, "Print",
      CellTags->"Info3212169303-1843986"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3212169303-1843986", 5778, 163}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 70, 0, 252, "Title"],
Cell[1778, 52, 82, 1, 78, "Subsubtitle"],
Cell[1863, 55, 281, 9, 194, "SmallText"],

Cell[CellGroupData[{
Cell[2169, 68, 27, 0, 89, "Section"],
Cell[2199, 70, 76, 0, 47, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2312, 75, 30, 0, 89, "Section"],
Cell[2345, 77, 81, 2, 42, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[2451, 83, 985, 18, 302, "Input"],
Cell[3439, 103, 135, 3, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3611, 111, 86, 1, 42, "Input"],
Cell[3700, 114, 71, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3808, 120, 48, 1, 42, "Input"],
Cell[3859, 123, 1191, 17, 535, "Print",
  CellTags->"Info3212169303-1843986"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

