(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5762,        199]*)
(*NotebookOutlinePosition[      6505,        226]*)
(*  CellTagsIndexPosition[      6461,        222]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Test etaOpt installation", "Title"],

Cell["Use this notebook to test your installation", "Text"],

Cell[CellGroupData[{

Cell["Variable Path", "Subsection"],

Cell["\<\
Your path should contain the installation directory of etaOpt\
\>", "Text"],

Cell[BoxData[
    \($Path\)], "Input",
  InitializationCell->True],

Cell["If not, you should append the path e.g.", "Text"],

Cell[BoxData[
    \(\(AppendTo[$Path, "\<~/pvsim/tmp/letay/etaOpt\>"];\)\)], "Input"],

Cell[TextData[{
  "You can add this line to your personal init.m which is evaluated each time \
the Mathematica kernel is started.\nYou can find init.m \n - for Linux under \
your home directoryor  under the installation directory of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " e.g.: /usr/local/math-",
  StyleBox["4.1/Configuration/Kernel/init.m",
    FontSlant->"Italic"],
  "\n - for Windows under the installation directory of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " e.g.: c:\\win32app\\",
  StyleBox["Mathematica\\4.1\\Configuration\\Kernel\\init.m",
    FontSlant->"Italic"]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["load package", "Subsection"],

Cell[BoxData[
    \(\(Needs /@ {"\<etaOpt`\>"};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["spectrumPath", "Subsection"],

Cell["This should give you the path where the spectra resides.", "Text"],

Cell[BoxData[
    \(spectrumPath /. Options[spectrum]\)], "Input",
  InitializationCell->True],

Cell["\<\
If this points to the wrong directory you can set it permanently by modifying \
the options for spectrum in etaOpt.m. To do this open etaopt.m in a \
texteditor like vi or Emacs or notepad and loke for
Options[spectrum]={spectrumPath\[Rule]\"./spectra\",... 
change \"./spectra\" to your location e.g. \"etaOpt_install_dir/spectra\"

If you only want to set the path temporary you can use the method \
setSpectrumPath\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["do a simple calculation", "Subsection"],

Cell["create spectrum blackbody 6000 K", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sp = spectrum . new[powerOfOneSun \[Rule] 1000]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    InterpretationBox["\<\"-\\!\\(spectrum\\)-\"\>",
      StringForm[ "-`1`-", spectrum],
      Editable->False]], "Output"]
}, Closed]],

Cell["setup a single junction ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eta = 
      etaOpt . new[name \[Rule] "\<single junction\>", 
          item \[Rule] \[IndentingNewLine]mechStack . 
              new[name \[Rule] "\<cell\>", 
                item \[Rule] {\[IndentingNewLine]\(monoStack . 
                          new[name \[Rule] "\<cell\>", 
                            item \[Rule] {\[IndentingNewLine]oneDiodeJunction \
. new[name \[Rule] "\<cell\>", temperature \[Rule] 293, no \[Rule] 1, 
                                    nu \[Rule] 
                                      0]\[IndentingNewLine]}]\
\[IndentingNewLine]spectrum \[Rule] 
                      sp\)\(,\)\[IndentingNewLine]}], \
\[IndentingNewLine]bandgapRange \[Rule] {{0.5, 2, 
                0.1}}\[IndentingNewLine]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    InterpretationBox["\<\"-\\!\\(etaOpt\\)-\"\>",
      StringForm[ "-`1`-", etaOpt],
      Editable->False]], "Output"]
}, Closed]],

Cell["perform the calculation", "Text"],

Cell[BoxData[
    \(\(eta . calcAll[];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["create a plot", "Subsection"],

Cell[BoxData[
    \(eta . plot[subset \[Rule] {x}]\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["export", "Subsection"],

Cell["export the data into... ", "Text"],

Cell[BoxData[
    \(Directory[] <> \((eta . generateFilename[])\)\)], "Input",
  InitializationCell->True],

Cell["\<\
If yes evaluate the following cell and look into the file above\
\>", "Text"],

Cell[BoxData[
    \(eta . export[subset \[Rule] {x}]\)], "Input"]
}, Closed]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{1272, 953},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowCellBracket->True,
ShowSelection->True,
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 41, 0, 175, "Title"],
Cell[1749, 52, 59, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[1833, 56, 35, 0, 64, "Subsection"],
Cell[1871, 58, 85, 2, 46, "Text"],
Cell[1959, 62, 66, 2, 58, "Input",
  InitializationCell->True],
Cell[2028, 66, 55, 0, 46, "Text"],
Cell[2086, 68, 85, 1, 39, "Input"],
Cell[2174, 71, 626, 15, 121, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2837, 91, 34, 0, 38, "Subsection"],
Cell[2874, 93, 90, 2, 58, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3001, 100, 34, 0, 38, "Subsection"],
Cell[3038, 102, 72, 0, 46, "Text"],
Cell[3113, 104, 94, 2, 58, "Input",
  InitializationCell->True],
Cell[3210, 108, 441, 9, 171, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3688, 122, 45, 0, 38, "Subsection"],
Cell[3736, 124, 48, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[3809, 128, 108, 2, 58, "Input",
  InitializationCell->True],
Cell[3920, 132, 139, 3, 58, "Output"]
}, Closed]],
Cell[4074, 138, 40, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[4139, 142, 790, 15, 242, "Input",
  InitializationCell->True],
Cell[4932, 159, 135, 3, 58, "Output"]
}, Closed]],
Cell[5082, 165, 39, 0, 46, "Text"],
Cell[5124, 167, 81, 2, 58, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5242, 174, 35, 0, 38, "Subsection"],
Cell[5280, 176, 91, 2, 58, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5408, 183, 28, 0, 38, "Subsection"],
Cell[5439, 185, 40, 0, 46, "Text"],
Cell[5482, 187, 106, 2, 58, "Input",
  InitializationCell->True],
Cell[5591, 191, 87, 2, 46, "Text"],
Cell[5681, 195, 65, 1, 39, "Input"]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

